@@ -44,12 +44,11 @@ from pudb.py3compat import PY3, raw_input, execfile
 CONFIG = load_config()
 save_config(CONFIG)
 
-HELP_TEXT = r"""\
-Welcome to PuDB, the Python Urwid debugger.
--------------------------------------------
-
-(This help screen is scrollable. Hit Page Down to see more.)
+HELP_HEADER = r"""
+Key Assignments: Use Arrow Down/Up or Page Down/Up to scroll.
+"""
 
+HELP_MAIN = r"""
 Keys:
     Ctrl-p - edit preferences
 
@@ -59,14 +58,13 @@ Keys:
     r/f - finish current function
     t - run to cursor
     e - show traceback [post-mortem or in exception state]
+    b - set/clear breakpoint
 
     H - move to current line (bottom of stack)
     u - move up one stack frame
     d - move down one stack frame
 
     o - show console/output screen
-
-    b - toggle breakpoint
     m - open module
 
     j/k - up/down
@@ -86,7 +84,6 @@ Keys:
     q - quit
 
     Ctrl-c - when in continue mode, break back to PuDB
-
     Ctrl-l - redraw screen
 
 Shell-related:
@@ -99,14 +96,16 @@ Shell-related:
     Ctrl-v - insert newline
     Ctrl-n/p - browse command line history
     Tab - yes, there is (simple) tab completion
+"""
 
+HELP_SIDE = r"""
 Sidebar-related (active in sidebar):
     +/- - grow/shrink sidebar
     _/= - minimize/maximize sidebar
     [/] - grow/shrink relative size of active sidebar box
 
 Keys in variables list:
-    \/space - expand/collapse
+    \/enter/space - expand/collapse
     t/r/s/c - show type/repr/str/custom for this variable
     h - toggle highlighting
     @ - toggle repetition at top
@@ -114,18 +113,19 @@ Keys in variables list:
     m - toggle method visibility
     w - toggle line wrapping
     n/insert - add new watch expression
-    enter - edit options (also to delete)
+    e - edit options (also to delete)
 
 Keys in stack list:
-
     enter - jump to frame
 
-Keys in breakpoints view:
-
-    enter - edit breakpoint
+Keys in breakpoints list:
+    enter - jump to breakpoint
+    b - toggle breakpoint
     d - delete breakpoint
-    e - enable/disable breakpoint
+    e - edit breakpoint
+"""
 
+HELP_LICENSE = r"""
 License:
 --------
 
@@ -701,10 +701,12 @@ class DebuggerUI(FrameVarInfoKeeper):
         self.cmdline_sigwrap = SignalWrap(
                 urwid.AttrMap(self.cmdline_pile, None, "focused sidebar")
                 )
-
+        self.cmdline_on = not CONFIG["hide_cmdline_win"]
+        self.cmdline_weight = 1
         self.lhs_col = urwid.Pile([
             ("weight", 5, self.source_attr),
-            ("weight", 1, self.cmdline_sigwrap),
+            ("weight", self.cmdline_weight if self.cmdline_on else 0,
+                self.cmdline_sigwrap),
             ])
 
         # }}}
@@ -760,7 +762,7 @@ class DebuggerUI(FrameVarInfoKeeper):
         def change_rhs_box(name, index, direction, w, size, key):
             from pudb.settings import save_config
 
-            _, weight = self.rhs_col.item_types[index]
+            weight = self.rhs_col.item_types[index][1]
 
             if direction < 0:
                 if weight > 1/5:
@@ -785,7 +787,7 @@ class DebuggerUI(FrameVarInfoKeeper):
             iinfo = self.get_frame_var_info(read_only=False) \
                     .get_inspect_info(var.id_path, read_only=False)
 
-            if key == "\\" or key == ' ':
+            if key == "enter" or key == "\\" or key == ' ':
                 iinfo.show_detail = not iinfo.show_detail
             elif key == "t":
                 iinfo.display_type = "type"
@@ -936,6 +938,9 @@ class DebuggerUI(FrameVarInfoKeeper):
                 fvi.watches.append(we)
                 self.update_var_view()
 
+        def helpside(w, size, key):
+            help(HELP_HEADER + HELP_SIDE + HELP_MAIN + HELP_LICENSE)
+
         self.var_list.listen("\\", change_var_state)
         self.var_list.listen(" ", change_var_state)
         self.var_list.listen("t", change_var_state)
@@ -947,7 +952,8 @@ class DebuggerUI(FrameVarInfoKeeper):
         self.var_list.listen("*", change_var_state)
         self.var_list.listen("w", change_var_state)
         self.var_list.listen("m", change_var_state)
-        self.var_list.listen("enter", edit_inspector_detail)
+        self.var_list.listen("enter", change_var_state)
+        self.var_list.listen("e", edit_inspector_detail)
         self.var_list.listen("n", insert_watch)
         self.var_list.listen("insert", insert_watch)
 
@@ -956,6 +962,8 @@ class DebuggerUI(FrameVarInfoKeeper):
 
         self.var_list.listen("j", self.rhs_scroll_down)
         self.var_list.listen("k", self.rhs_scroll_up)
+        self.var_list.listen("f1", helpside)
+        self.var_list.listen("?", helpside)
 
         # }}}
 
@@ -984,6 +992,8 @@ class DebuggerUI(FrameVarInfoKeeper):
 
         self.stack_list.listen("j", self.rhs_scroll_down)
         self.stack_list.listen("k", self.rhs_scroll_up)
+        self.stack_list.listen("f1", helpside)
+        self.stack_list.listen("?", helpside)
 
         # }}}
 
@@ -1099,16 +1109,28 @@ class DebuggerUI(FrameVarInfoKeeper):
                 else:
                     self.update_breakpoints()
 
-        self.bp_list.listen("enter", examine_breakpoint)
+        def show_breakpoint(w, size, key):
+            bp_entry, pos = self.bp_list._w.get_focus()
+
+            if bp_entry is not None:
+                bp = self._get_bp_list()[pos]
+                self.show_line(bp.line,
+                        FileSourceCodeProvider(self.debugger, bp.file))
+
+        self.bp_list.listen("enter", show_breakpoint)
         self.bp_list.listen("d", delete_breakpoint)
         self.bp_list.listen("s", save_breakpoints)
-        self.bp_list.listen("e", enable_disable_breakpoint)
+        self.bp_list.listen("e", examine_breakpoint)
+        self.bp_list.listen("b", enable_disable_breakpoint)
+        self.bp_list.listen("H", move_stack_top)
 
         self.bp_list.listen("[", partial(change_rhs_box, 'breakpoints', 2, -1))
         self.bp_list.listen("]", partial(change_rhs_box, 'breakpoints', 2, 1))
 
         self.bp_list.listen("j", self.rhs_scroll_down)
         self.bp_list.listen("k", self.rhs_scroll_up)
+        self.bp_list.listen("f1", helpside)
+        self.bp_list.listen("?", helpside)
         # }}}
 
         # {{{ source listeners
@@ -1433,6 +1455,9 @@ class DebuggerUI(FrameVarInfoKeeper):
                         self.debugger.set_frame_index(
                                 self.translate_ui_stack_index(pos))
 
+        def helpmain(w, size, key):
+            help(HELP_HEADER + HELP_MAIN + HELP_SIDE + HELP_LICENSE)
+
         self.source_sigwrap.listen("n", next)
         self.source_sigwrap.listen("s", step)
         self.source_sigwrap.listen("f", finish)
@@ -1465,6 +1490,8 @@ class DebuggerUI(FrameVarInfoKeeper):
         self.source_sigwrap.listen("H", move_stack_top)
         self.source_sigwrap.listen("u", move_stack_up)
         self.source_sigwrap.listen("d", move_stack_down)
+        self.source_sigwrap.listen("f1", helpmain)
+        self.source_sigwrap.listen("?", helpmain)
 
         # }}}
 
@@ -1668,8 +1695,14 @@ class DebuggerUI(FrameVarInfoKeeper):
         def toggle_cmdline_focus(w, size, key):
             self.columns.set_focus(self.lhs_col)
             if self.lhs_col.get_focus() is self.cmdline_sigwrap:
-                self.lhs_col.set_focus(self.source_attr)
+                if CONFIG["hide_cmdline_win"]:
+                    self.set_cmdline_state(False)
+                self.lhs_col.set_focus(self.search_controller.search_AttrMap
+                        if self.search_controller.search_box else
+                        self.source_attr)
             else:
+                if CONFIG["hide_cmdline_win"]:
+                    self.set_cmdline_state(True)
                 self.cmdline_pile.set_focus(self.cmdline_edit_bar)
                 self.lhs_col.set_focus(self.cmdline_sigwrap)
 
@@ -1688,30 +1721,29 @@ class DebuggerUI(FrameVarInfoKeeper):
         self.top.listen("ctrl x", toggle_cmdline_focus)
 
         # {{{ command line sizing
+        def set_cmdline_default_size(weight):
+            self.cmdline_weight = weight
+            self.set_cmdline_size()
 
         def max_cmdline(w, size, key):
-            self.lhs_col.item_types[-1] = "weight", 5
-            self.lhs_col._invalidate()
+            set_cmdline_default_size(5)
 
         def min_cmdline(w, size, key):
-            self.lhs_col.item_types[-1] = "weight", 1/2
-            self.lhs_col._invalidate()
+            set_cmdline_default_size(1/2)
 
         def grow_cmdline(w, size, key):
-            _, weight = self.lhs_col.item_types[-1]
+            weight = self.cmdline_weight
 
             if weight < 5:
                 weight *= 1.25
-                self.lhs_col.item_types[-1] = "weight", weight
-                self.lhs_col._invalidate()
+                set_cmdline_default_size(weight)
 
         def shrink_cmdline(w, size, key):
-            _, weight = self.lhs_col.item_types[-1]
+            weight = self.cmdline_weight
 
             if weight > 1/2:
                 weight /= 1.25
-                self.lhs_col.item_types[-1] = "weight", weight
-                self.lhs_col._invalidate()
+                set_cmdline_default_size(weight)
 
         self.cmdline_sigwrap.listen("=", max_cmdline)
         self.cmdline_sigwrap.listen("+", grow_cmdline)
@@ -1747,7 +1779,7 @@ class DebuggerUI(FrameVarInfoKeeper):
         def grow_sidebar(w, size, key):
             from pudb.settings import save_config
 
-            _, weight = self.columns.column_types[1]
+            weight = self.columns.column_types[1][1]
 
             if weight < 5:
                 weight *= 1.25
@@ -1759,7 +1791,7 @@ class DebuggerUI(FrameVarInfoKeeper):
         def shrink_sidebar(w, size, key):
             from pudb.settings import save_config
 
-            _, weight = self.columns.column_types[1]
+            weight = self.columns.column_types[1][1]
 
             if weight > 1/5:
                 weight /= 1.25
@@ -1881,8 +1913,8 @@ class DebuggerUI(FrameVarInfoKeeper):
         def redraw_screen(w, size, key):
             self.screen.clear()
 
-        def help(w, size, key):
-            self.message(HELP_TEXT, title="PuDB Help")
+        def help(pages):
+            self.message(pages, title="PuDB - The Python Urwid Debugger")
 
         self.top.listen("o", show_output)
         self.top.listen("ctrl r", reload_breakpoints)
@@ -1897,8 +1929,6 @@ class DebuggerUI(FrameVarInfoKeeper):
         self.top.listen("q", quit)
         self.top.listen("ctrl p", do_edit_config)
         self.top.listen("ctrl l", redraw_screen)
-        self.top.listen("f1", help)
-        self.top.listen("?", help)
 
         # }}}
 
@@ -1961,13 +1991,27 @@ class DebuggerUI(FrameVarInfoKeeper):
     # }}}
 
     # {{{ UI helpers
+    def reset_cmdline_size(self):
+        self.lhs_col.item_types[-1] = "weight", \
+                self.cmdline_weight if self.cmdline_on else 0
+
+    def set_cmdline_size(self, weight=None):
+        if weight is None:
+            weight = self.cmdline_weight
+
+        self.lhs_col.item_types[-1] = "weight", weight
+        self.lhs_col._invalidate()
+
+    def set_cmdline_state(self, state_on):
+        if state_on != self.cmdline_on:
+            self.cmdline_on = state_on
+            self.set_cmdline_size(None if state_on else 0)
+
     def rhs_scroll_down(self, w, size, key):
-        if key == 'j' and CONFIG['jk_sidebar_scroll']:
-            w.keypress(size, "down")
+        w.keypress(size, "down")
 
     def rhs_scroll_up(self, w, size, key):
-        if key == 'k' and CONFIG['jk_sidebar_scroll']:
-            w.keypress(size, "up")
+        w.keypress(size, "up")
 
     def translate_ui_stack_index(self, index):
         # note: self-inverse
@@ -2163,7 +2207,7 @@ class DebuggerUI(FrameVarInfoKeeper):
                 self.message("Package 'pygments' not found. "
                         "Syntax highlighting disabled.")
 
-        WELCOME_LEVEL = "e035"  # noqa
+        WELCOME_LEVEL = "e036"  # noqa
         if CONFIG["seen_welcome"] < WELCOME_LEVEL:
             CONFIG["seen_welcome"] = WELCOME_LEVEL
             from pudb import VERSION
@@ -2180,9 +2224,18 @@ class DebuggerUI(FrameVarInfoKeeper):
                     "(invoked by hitting '?' after this message) should get you "
                     "on your way.\n"
 
+                    "\nChanges in version 2019.2:\n\n"
+                    "- Auto-hide the command line (Mark Blakeney)\n"
+                    "- Improve help and add jump to breakpoint (Mark Blakeney)\n"
+                    "- Drop Py2.6 support\n"
+                    "- Show callable attributes in var view\n"
+                    "- Allow scrolling sidebar with j/k\n"
+                    "- Fix setting breakpoints in Py3.8 (Aaron Meurer)\n"
+
                     "\nChanges in version 2019.1:\n\n"
                     "- Allow 'space' as a key to expand variables (Enrico Troeger)\n"
-                    "- Have a persistent setting on variable visibility (Enrico Troeger)\n"
+                    "- Have a persistent setting on variable visibility \n"
+                    "  (Enrico Troeger)\n"
                     "- Enable/partially automate opening the debugger in another \n"
                     "  terminal (Anton Barkovsky)\n"
                     "- Make sidebar scrollable with j/k (Clayton Craft)\n"
@@ -2490,6 +2543,9 @@ class DebuggerUI(FrameVarInfoKeeper):
 
         self.stack_walker[:] = frame_uis
 
+    def update_cmdline_win(self):
+        self.set_cmdline_state(not CONFIG["hide_cmdline_win"])
+
     # }}}
 
 # vim: foldmethod=marker:expandtab:softtabstop=4
