@@ -11,6 +11,13 @@ except ImportError:
 else:
     HAVE_BPYTHON = True
 
+try:
+    from ptpython.ipython import embed as ptipython_embed
+except ImportError:
+    HAVE_PTIPYTHON = False
+else:
+    HAVE_PTIPYTHON = True
+
 try:
     from ptpython.repl import embed as ptpython_embed, run_config
 except ImportError:
@@ -231,10 +238,19 @@ def run_ipython_shell(globals, locals):
 def run_ptpython_shell(globals, locals):
     # Use the default ptpython history
     import os
-    history_filename = os.path.expanduser('~/.ptpython_history')
-    ptpython_embed(globals.copy(), locals.copy(),
+    history_filename = os.path.expanduser('~/.ptpython/history')
+    ptpython_embed(globals=globals.copy(), locals=locals.copy(),
                    history_filename=history_filename,
                    configure=run_config)
 
 
+def run_ptipython_shell(globals, locals):
+    # Use the default ptpython history
+    import os
+
+    history_filename = os.path.expanduser('~/.ptpython/history')
+    ptipython_embed(globals=globals.copy(), locals=locals.copy(),
+                   history_filename=history_filename,
+                   configure=run_config)
+
 # vim: foldmethod=marker
